pub enum CompletionConfig {
Mode(CompletionMode),
Except(ExceptRules),
Strict(StrictRules),
}Expand description
Lets the user configure how the property completion should happen. There are two main modes: strict and loose (default) On loose, the editor will suggest anything, not caring about the domain. On strict, the editor will only suggest property that have a matching domain or anything if the type could not be determined.
Both options can be specialized, ie only strict on these properties or only loose on these properties.
For example { loose: [“http://www.w3.org/2000/01/rdf-schema#”] }, here the editor will be strict, and show properties from rdfs On the other hand { strict: [“http://www.w3.org/ns/shacl#”] }, here the editor will be loose, and only show shacl properties if the objects is the correct type
Variants
Implementations
Sourceimpl CompletionConfig
impl CompletionConfig
pub fn correct_domain_required(&self, property: &str) -> bool