pub struct LocalConfig {
pub ontologies: HashSet<String>,
pub shapes: HashSet<String>,
pub disabled: HashSet<Disabled>,
pub prefix_disabled: HashSet<String>,
pub completion: CompletionConfig,
pub prefix_format: Option<PrefixFormat>,
pub closed_namespaces: HashSet<String>,
pub allowed_properties: HashSet<String>,
}Fields
ontologies: HashSet<String>Extra ontologies to import
shapes: HashSet<String>Extra shapes to import
disabled: HashSet<Disabled>Features to disable
prefix_disabled: HashSet<String>disable which prefices from prefix.cc to show
completion: CompletionConfigconfiure completion behavior
prefix_format: Option<PrefixFormat>Preferred way to write Turtle/TriG prefix declarations when inserting them.
closed_namespaces: HashSet<String>Namespaces for which IRIs used as properties (predicates) must be defined in a
known ontology. Predicate IRIs that start with one of these namespaces but are
not a known property (and not in [allowed_properties]) are flagged with a warning.
allowed_properties: HashSet<String>User-approved property IRIs that should not be flagged by the
[closed_namespaces] validation, even though they are absent from the ontology.
Implementations
Sourceimpl LocalConfig
impl LocalConfig
Sourcepub fn is_disabled(&self, d: Disabled) -> bool
pub fn is_disabled(&self, d: Disabled) -> bool
Whether the given feature/diagnostic has been disabled by the user.
Sourcepub fn combine(&mut self, other: LocalConfig)
pub fn combine(&mut self, other: LocalConfig)
Combines this config with another config, giving precedence to the other config
pub fn global_url() -> Option<Url>
pub async fn global(fs: &Fs) -> Option<Self>
Sourcepub async fn persist_allowed_property(fs: &Fs, iri: &str) -> Option<()>
pub async fn persist_allowed_property(fs: &Fs, iri: &str) -> Option<()>
Add iri to the global config’s allowed_properties array on disk,
preserving the rest of the existing global configuration. Used by the
swls.allowProperty command so the user’s choice survives restarts.
pub async fn local(fs: &Fs, url: &Url) -> Option<Self>