CommandReceiver

Struct CommandReceiver 

pub struct CommandReceiver(pub UnboundedReceiver<CommandQueue>);
Resource used to receive command queues. These command queues are handled with handle_tasks.

Tuple Fields

0: UnboundedReceiver<CommandQueue>

Methods from Deref<Target = UnboundedReceiver<CommandQueue>>

pub fn recv(&mut self) -> Recv<'_, UnboundedReceiver<T>>

Waits for a message from the channel. If the channel is empty and closed, returns RecvError.

pub fn close(&mut self)

Closes the receiving half of a channel, without dropping it.

This prevents any further messages from being sent on the channel while still enabling the receiver to drain messages that are buffered.

pub fn try_next(&mut self) -> Result<Option<T>, TryRecvError>

👎Deprecated:

please use try_recv instead

Tries to receive the next message without notifying a context if empty.

It is not recommended to call this function from inside of a future, only when you’ve otherwise arranged to be notified when the channel is no longer empty.

This function returns:

  • Ok(Some(t)) when message is fetched
  • Ok(None) when channel is closed and no messages left in the queue
  • Err(e) when there are no messages available, but channel is not yet closed
pub fn try_recv(&mut self) -> Result<T, TryRecvError>

Tries to receive a message from the channel without blocking. If the channel is empty, or empty and closed, this method returns an error.